==> haskell-libbf-0.6.6-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libbf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 libBF
version:              0.6.6
visibility:           public
id:                   libBF-0.6.6-4eXHi6nrvAx3MUCjqxLChh
key:                  libBF-0.6.6-4eXHi6nrvAx3MUCjqxLChh
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A binding to the libBF library.
description:
    LibBF is a C library for working with arbitray precision
    IEEE 754 floating point numbers.

category:             Data
abi:                  ac1af5cf962a54357162f3c7feb1d859
exposed:              True
exposed-modules:      LibBF LibBF.Mutable LibBF.Opts
import-dirs:          /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libbf
hs-libraries:         HSlibBF-0.6.6-4eXHi6nrvAx3MUCjqxLChh
extra-libraries:      bf
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-AkdCWGE5Cqm4vrMrQip090

haddock-interfaces:   /usr/share/doc/haskell-libbf/html/libBF.haddock
haddock-html:         /usr/share/doc/haskell-libbf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libbf-0.6.6-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libbf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 libBF
version:              0.6.6
visibility:           public
id:                   libBF-0.6.6-5qv8wJf3502KmEsDpqLZuv
key:                  libBF-0.6.6-5qv8wJf3502KmEsDpqLZuv
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A binding to the libBF library.
description:
    LibBF is a C library for working with arbitray precision
    IEEE 754 floating point numbers.

category:             Data
abi:                  e7a9e15b55babf228d3a1d8797d9755c
exposed:              True
exposed-modules:      LibBF LibBF.Mutable LibBF.Opts
import-dirs:          /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libbf
hs-libraries:         HSlibBF-0.6.6-5qv8wJf3502KmEsDpqLZuv
extra-libraries:      bf
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-9Up8LPJnqTG92zCMBiHaIh

haddock-interfaces:   /usr/share/doc/haskell-libbf/html/libBF.haddock
haddock-html:         /usr/share/doc/haskell-libbf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
